Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(576)

Unified Diff: chrome/browser/cocoa/extensions/extension_action_context_menu.h

Issue 595017: [Mac] Use the ExtensionToolbarModel for ordering of the Browser Actions. Prep... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Remove redundant profile object. Created 10 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/cocoa/extensions/extension_action_context_menu.h
===================================================================
--- chrome/browser/cocoa/extensions/extension_action_context_menu.h (revision 38554)
+++ chrome/browser/cocoa/extensions/extension_action_context_menu.h (working copy)
@@ -9,8 +9,9 @@
#import <Cocoa/Cocoa.h>
+class AsyncUninstaller;
class Extension;
-class AsyncUninstaller;
+class Profile;
// A context menu used by the Browser and Page Action components that appears
// if a user right-clicks the view of the given extension.
@@ -18,13 +19,16 @@
// The extension that this menu belongs to. Weak.
Extension* extension_;
+ // The browser profile of the window that contains this extension. Weak.
+ Profile* profile_;
+
// Used to load the extension icon asynchronously on the I/O thread then show
// the uninstall confirmation dialog.
scoped_refptr<AsyncUninstaller> uninstaller_;
}
-// Initializes and returns a context menu for the given extension.
-- (id)initWithExtension:(Extension*)extension;
+// Initializes and returns a context menu for the given extension and profile.
+- (id)initWithExtension:(Extension*)extension profile:(Profile*)profile;
@end

Powered by Google App Engine
This is Rietveld 408576698